document.addEventListener("DOMContentLoaded", function () {
  var starmapPath = document.querySelector("#trail-path path");
  var sections = document.querySelectorAll(".js-section");
  var points = document.querySelectorAll("#Points_of_Interest circle");

  var pathLength = starmapPath.getTotalLength();
  starmapPath.style.strokeDasharray = pathLength;
  starmapPath.style.strokeDashoffset = pathLength;

  // Initialize the active point index
  var activePointIndex = -1;

  // Set the initial state of the points based on the first section
  var initialZoomStart = parseFloat(sections[0].getAttribute("data-zoom-start"));
  points.forEach(function (point, index) {
    var initialOffset = pathLength - pathLength * initialZoomStart;
    point.style.fill = index === 0 ? "#FF7788" : "#EFF0F2";
    point.style.transition = "fill 0.3s ease-in-out, transform 0.3s ease-in-out";
    starmapPath.style.strokeDashoffset = initialOffset;

    // Set transform-origin to the center of the circle
    point.style.transformOrigin = "center center";
    point.style.transform = index === 0 ? "scale(1.1)" : "scale(1)";
  });

  function handleScroll() {
    var scrollPercentage = window.scrollY / (document.documentElement.scrollHeight - window.innerHeight);
    var currentSectionIndex = Math.floor(scrollPercentage * sections.length);

    // Assuming each section has the "data-zoom-start" attribute
    var zoomStart = parseFloat(sections[currentSectionIndex].getAttribute("data-zoom-start"));

    // Calculate the position of the starmap path
    starmapPath.style.strokeDashoffset = pathLength - pathLength * zoomStart;

    // Reset all points to original color and size
    points.forEach(function (point) {
      point.style.fill = "#EFF0F2";
      point.style.transform = "scale(1)";
    });

    // Check if the currentSectionIndex is within the bounds of the points
    if (currentSectionIndex >= 0 && currentSectionIndex < points.length) {
      // Apply color change and zoom effect for the corresponding point
      activePointIndex = currentSectionIndex;
      var currentPoint = points[activePointIndex];
      currentPoint.style.fill = "#FF7788";
      currentPoint.style.transform = "scale(1.001)";
    } else {
      // No section found, reset the active point
      activePointIndex = -1;
    }
  }

  window.addEventListener("scroll", handleScroll);

  // Trigger handleScroll once to set the initial state
  handleScroll();
});

